aboutsummaryrefslogtreecommitdiff
path: root/compiler/src/dotty/tools/dotc/core/Constraint.scala
diff options
context:
space:
mode:
authorMartin Odersky <odersky@gmail.com>2017-03-18 11:26:59 +0100
committerMartin Odersky <odersky@gmail.com>2017-04-06 13:15:28 +0200
commitdb4f7a19c9329d59da09a4de6b8476b4b6988cdf (patch)
treee70a1cf2d4af3a9e3e4b3999d5000b4466627143 /compiler/src/dotty/tools/dotc/core/Constraint.scala
parent26497bb3c654e294a48db2098978bc77b11f2889 (diff)
downloaddotty-db4f7a19c9329d59da09a4de6b8476b4b6988cdf.tar.gz
dotty-db4f7a19c9329d59da09a4de6b8476b4b6988cdf.tar.bz2
dotty-db4f7a19c9329d59da09a4de6b8476b4b6988cdf.zip
Further refactorings
- Use TypeLambda instead of PolyType. - Further harmonize factory operations
Diffstat (limited to 'compiler/src/dotty/tools/dotc/core/Constraint.scala')
-rw-r--r--compiler/src/dotty/tools/dotc/core/Constraint.scala8
1 files changed, 4 insertions, 4 deletions
diff --git a/compiler/src/dotty/tools/dotc/core/Constraint.scala b/compiler/src/dotty/tools/dotc/core/Constraint.scala
index 7a0e6dece..a6c21c0d1 100644
--- a/compiler/src/dotty/tools/dotc/core/Constraint.scala
+++ b/compiler/src/dotty/tools/dotc/core/Constraint.scala
@@ -14,7 +14,7 @@ import config.Printers.constr
* over values of the following types:
*
* - TypeLambda A constraint constrains the type parameters of a set of TypeLambdas
* - TypeParamRef The parameters of the constrained polytypes
* - TypeVar Every constrained parameter might be associated with a TypeVar
* that has the TypeParamRef as origin.
*/
@@ -120,10 +120,10 @@ abstract class Constraint extends Showable {
/** A new constraint with all entries coming from `pt` removed. */
def remove(pt: TypeLambda)(implicit ctx: Context): This
- /** The polytypes constrained by this constraint */
- def domainPolys: List[TypeLambda]
+ /** The type lambdas constrained by this constraint */
+ def domainLambdas: List[TypeLambda]
- /** The polytype parameters constrained by this constraint */
+ /** The type lambda parameters constrained by this constraint */
def domainParams: List[TypeParamRef]
/** Check whether predicate holds for all parameters in constraint */
@@ -14,7 +14,7 @@ import config.Printers.constr
*
* - TypeLambda A constraint constrains the type parameters of a set of TypeLambdas
- * - TypeParamRef The parameters of the constrained polytypes
+ * - TypeParamRef The parameters of the constrained type lambdas
* - TypeVar Every constrained parameter might be associated with a TypeVar
* that has the TypeParamRef as origin.